import React, { FC, useState } from "react";
import {
    BrowserRouter as Router,
    Route,
    Link,
    Redirect,
    Switch,
} from "react-router-dom";

import Container from "@material-ui/core/Container";
import AppBar from "@material-ui/core/AppBar";
import Toolbar from "@material-ui/core/Toolbar";
import Button from "@material-ui/core/Button";
import { makeStyles } from "@material-ui/core/styles";
import { createMuiTheme, MuiThemeProvider } from "@material-ui/core";

import "./App.css";

import Login from "./pages/Login";
import About from "./pages/About";
import Home from "./pages/Home";
import Users from "./pages/Users";
import Notfound from "./pages/NotFound";

// Constants specifying lohin info
export const admin = "admin";
export const adminPassword = "123";

// MUI theme override
// TODO: Customize default MUI theme
const ourTheme = createMuiTheme({
    palette: {
        primary: {
            main: "#9B61FF",
        },
        secondary: {
            main: "#FFF861",
        },
    },
});

// Some useful css classes you may use
const useStyles = makeStyles((theme) => ({
    menuButton: { marginRight: theme.spacing(2) },
    link: { textDecoration: "none" },
}));

const App: FC = () => {
    // Styles
    const classes = useStyles();

    // Login state
    const [isLoggedIn, setIsLoggedIn] = useState(false);

    // Handler that checks if correct username and passord was provided
    // For now we will be using constant login info { name: 'admin', pw: '123' }
    const authorizeUser = (username: string, password: string) => {
        const isAuthorized = username === admin && password === adminPassword;
        setIsLoggedIn(isAuthorized);
        return isAuthorized;
    };

    return (
        // TODO: Add MuiThemeProvider with your custom theme
        <MuiThemeProvider theme={ourTheme}>
            <Router>
                <AppBar color="primary" position="static" variant="outlined">
                    {/* Navigation will be rendered on all pages */}
                    <Toolbar>
                        {/* TODO: render links to other pages based on whether user is logged in */}
                        {/* Hints: use Link component from react-router-dom + Button from MUI */}
                        {/* Add one route with non-existent route to test NotFound page */}
                        <Link className={classes.link} to="/">
                            <Button className={classes.menuButton}>Home</Button>
                        </Link>
                        {!isLoggedIn && (
                            <Link className={classes.link} to="/login">
                                <Button className={classes.menuButton}>
                                    Login
                                </Button>
                            </Link>
                        )}
                        {isLoggedIn && (
                            <>
                                {/* TODO: links */}
                                <Link className={classes.link} to="/about">
                                    <Button className={classes.menuButton}>
                                        About
                                    </Button>
                                </Link>
                                <Link className={classes.link} to="/users">
                                    <Button className={classes.menuButton}>
                                        Users
                                    </Button>
                                </Link>
                                <Link className={classes.link} to="/foo">
                                    <Button className={classes.menuButton}>
                                        Foo
                                    </Button>
                                </Link>
                            </>
                        )}
                    </Toolbar>
                </AppBar>

                <Redirect to={isLoggedIn ? "/" : "/login"} />

                <main className="App">
                    <Container maxWidth="sm">
                        <Switch>
                            {/* TODO: add routes to Home, Login, About, Users and NotFound components */}
                            {/* Hint: you need to pass "authorizeUser" prop to Login component, */}
                            {/*       so instead of <Route component={...} /> use <Route render={...} /> */}
                            <Route path="/" exact component={Home} />
                            <Route
                                path="/login"
                                exact
                                render={() => (
                                    <Login authorizeUser={authorizeUser} />
                                )}
                            />
                            <Route path="/about" exact component={About} />
                            <Route path="/users" exact component={Users} />
                            <Route component={Notfound} />
                        </Switch>
                    </Container>
                </main>
            </Router>
        </MuiThemeProvider>
    );
};

export default App;
