import React, { FC, useState } from "react";

import Card from "@material-ui/core/Card";
import CardActions from "@material-ui/core/CardActions";
import CardContent from "@material-ui/core/CardContent";
import Button from "@material-ui/core/Button";
import Typography from "@material-ui/core/Typography";
import TextField from "@material-ui/core/TextField";
import Link from "@material-ui/core/Link";

import { ReactComponent as Logo } from "./logo.svg";

type Props = {
    authorizeUser: (user: string, password: string) => boolean;
};

const Login: FC<Props> = ({ authorizeUser }) => {
    const [user, setUser] = useState("");
    const [password, setPassword] = useState("");
    const [error, setError] = useState(false);

    return (
        <Card>
            <CardContent>
                <Logo width={100} />
                <Typography variant="h5" component="h1">
                    Sign in
                </Typography>
                <Typography variant="subtitle1">Use your Account</Typography>
                <TextField
                    label="Email"
                    type="email"
                    name="email"
                    fullWidth
                    autoComplete="email"
                    margin="normal"
                    variant="outlined"
                    value={user}
                    // TODO: add onChange method
                    onChange={(e) => setUser(e.target.value)}
                />
                <TextField
                    label="Password"
                    type="password"
                    name="password"
                    fullWidth
                    margin="normal"
                    variant="outlined"
                    value={password}
                    // TODO: add onChange method
                    onChange={(e) => setPassword(e.target.value)}
                />
                {error && (
                    <Typography variant="subtitle2" align="left" color="error" paragraph>
                        <b>Wrong credentials</b>
                    </Typography>
                )}
                <Typography variant="subtitle2" align="left" paragraph>
                    <Link>
                        <b>Forgot email?</b>
                    </Link>
                </Typography>
                <Typography variant="subtitle2" align="left" paragraph>
                    Not your device? Use Guest mode to sign in privately.{" "}
                    <Link>Learn more</Link>
                </Typography>
            </CardContent>
            <CardActions>
                <Button variant="text" size="large" color="primary">
                    Create account
                </Button>
                <Button
                    variant="text"
                    size="large"
                    color="primary"
                    // TODO: finish login button by adding onClick
                    onClick={() => setError(!authorizeUser(user, password))}
                >
                    Login
                </Button>
            </CardActions>
        </Card>
    );
};

export default Login;
